@@ -4,7 +4,7 @@ use utf8; # encoding="utf-8"
 use warnings;
 use strict;
 
-our $VERSION = '0.11';
+our $VERSION = '0.2';
 
 use Acme::CPANAuthors::Register (
 	ABALAMA   => 'Lepenkov Sergey',
@@ -15,7 +15,6 @@ use Acme::CPANAuthors::Register (
 	ALEXEYT   => 'Alexey Toptygin',
 	ALGDR     => 'Aleksandr Guidrevitch',
 	AMALTSEV  => 'Andrew Maltsev',
-	AML       => 'Alexander Lourier',
 	ANDY      => 'Andrew Shitov',
 	APLA      => 'Иван Бахчеев',
 	ARTO      => 'Artur Penttinen',
@@ -23,12 +22,12 @@ use Acme::CPANAuthors::Register (
 	ATOURBIN  => 'Alexey Tourbin',
 	AVP       => 'Alexey V. Presnyakov',
 	BASHLOV   => 'Dmitry Bashlov',
+	BEROV     => 'Красимир Беров',
 	BOSU      => 'Boris Sukholitko',
 	BUTILW    => 'Ilya Butakov',
-	BWIZARD   => 'Arapov Denis',
 	CATONE    => 'Denis Pokataev',
 	CLEONTY   => 'Леонтий Чудинов',
-	DARKNOS   => 'Sergey Nosenko',
+	CYBER     => 'Ivan M Nanev',
 	DAVINCHI  => 'Pavel Boldin',
 	DEEMON    => 'Dmitry Dorofeev',
 	DESPAIR   => 'Walery Studennikov',
@@ -38,6 +37,9 @@ use Acme::CPANAuthors::Register (
 	DMOW      => 'Dmitry Ovsyanko',
 	DPETROV   => 'Denis Petrov',
 	DSAMZA    => 'Dmitry Sagaev',
+	DZHARIY   => 'Дмитрий Жарий',
+	EGORSH    => 'Egor Shipovalov',
+	EJS       => 'Eugen Sobchenko',
 	FEDOROV   => 'Dmitry Fedorov',
 	GARIEV    => 'Igor Gariev',
 	GDSL      => 'Sergey Skvortsov',
@@ -46,6 +48,8 @@ use Acme::CPANAuthors::Register (
 	GRAYKOT   => 'Sergey Kotenko',
 	GRIAN     => 'Анатолий Гришаев',
 	GRISHACE  => 'Gregory Belenky',
+	GRUBER    => 'Anton Berezin',
+	GUGU      => 'Андрей Костенко',
 	ICHE      => 'Ilya Chelpanov',
 	ICHUDOV   => 'Igor Chudov',
 	IFROL     => 'Иван Фролков',
@@ -60,14 +64,12 @@ use Acme::CPANAuthors::Register (
 	KLIMKIN   => 'Alexey Klimkin',
 	KOTEROV   => 'Dmitry Koterov',
 	KPV       => 'Pavel V. Kaygorodov',
-	KSURI     => 'Aleksey Surikov',
 	KVENTIN   => 'Константин Матюхин',
 	LEO       => 'Черепанов Леонид',
 	LESV      => 'Suhanov Vadim',
 	LEXUS     => 'Usanov Alexey',
 	LIOL      => 'Lobanov Igor',
 	LOGVINON  => 'Nikolay Logvinov',
-	LONERR    => 'Oleg A. Mamontov',
 	MAKAROW   => 'Andrew V. Makarow',
 	MAXICO    => 'Maxim Kashliak',
 	MBASOV    => 'Михаил В. Басов',
@@ -75,17 +77,21 @@ use Acme::CPANAuthors::Register (
 	MONS      => 'Mons Anderson',
 	MPG       => 'Maxim  Grigoriev',
 	NICKOLA   => 'Nickolay Kovalev',
+	NIKIP     => 'Nikolay Pelov',
+	NIKOLAY   => 'Nikolay Bachiyski',
 	NRG       => 'Odintsov Pavel',
-	NUF       => 'Dmitry Smal',
 	OLEGSHER  => 'Oleg Sher',
 	OLEKO     => 'Oleg Kobyakovskiy',
+	OMEGA     => 'Десислав Каменов/Desislav Kamenov',
+	PANOLEX   => 'Олександр Панчук',
 	PLISCO    => 'Igor Plisco',
 	PRO       => 'Oleg Alexeenkov',
 	PSMIRNOV  => 'Pavel Smirnov',
+	QUEVLAR   => 'Igor Sanchez-Puls',
 	RADKOV    => 'Alexey Radkov',
 	RHIZO     => 'Dmitry Karabanov',
 	RIIKI     => 'Oleg Prokopyev',
-	ROWAA     => 'Олег Rowaa[SR13] В. Волков',
+	ROWAA     => 'Олег &quot;Rowaa[SR13]&quot; В. Волков',
 	RUDENKO   => 'Alexei Rudenko',
 	RUSAKOV   => 'Sergey Rusakov',
 	RUZ       => 'Ruslan U. Zakirov',
@@ -96,6 +102,7 @@ use Acme::CPANAuthors::Register (
 	SERGEY    => 'Sergey Gribov',
 	SERGEYCHE => 'Sergey Chernyshev',
 	SHARIFULN => 'Анатолий Шарифулин',
+	SKOLYCHEV => 'Sergey V. Kolychev',
 	SNEMAROV  => 'Sergei A. Nemarov',
 	SPECTRUM  => 'Черненко Эдуард Павлович',
 	STELLAR   => 'Andrei V. Shetuhin',
@@ -105,23 +112,27 @@ use Acme::CPANAuthors::Register (
 	SYP       => 'Станислав Пусеп',
 	TOLIKL    => 'Anatoly K. Lasareff',
 	TOYVO     => 'Anton Tayanovskyy',
-	UNERA     => 'Dmitry E. Oboukhov',
+	TTOD      => 'Тодор Тодоров',
 	USTIANSKY => 'Vadim O. Ustiansky',
+	VADIM     => 'Vadim Ponomarenko',
 	VADIML    => 'Vadim Likhota (Вадим Лихота)',
+	VADIMT    => 'Vadim Trochinsky',
 	VANY      => 'Ivan B. Serezhkin',
 	VICTORI   => 'Victor Igumnov',
+	VIY       => 'Igor Yu. Vlasenko',
 	VKON      => 'Vadim Konovalov',
 	VLADB     => 'Vladimir Bogdanov',
 	VOVKASM   => 'Vladimir Timofeev',
+	VTI       => 'Вячеслав Тихановский',
 	XFIRE     => 'Ilya Obshadko',
 	YKAR      => 'Yuri Karaban',
 	YKOSTYLEV => 'Yuri Kostylev',
 	YURAN     => 'Nevinitsin Yury',
-	ZAG       => 'Zahatski Aliaksandr',
 	ZMIJ      => 'Sergei A. Fedorov',
 	ZOFFIX    => 'Zoffix Znet',
 );
 
+
 1;
 __END__
 
@@ -135,14 +146,14 @@ Acme::CPANAuthors::Russian - We are Russian CPAN authors
 
     use Acme::CPANAuthors;
 
-    my $authors  = Acme::CPANAuthors->new('Russian');
+    my $authors  = Acme::CPANAuthors->new("Russian");
 
     my $number   = $authors->count;
     my @ids      = $authors->id;
-    my @distros  = $authors->distributions("KAPPA");
-    my $url      = $authors->avatar_url("SHARIFULN");
+    my @distros  = $authors->distributions("ZOFFIX");
+    my $url      = $authors->avatar_url("ZOFFIX");
     my $kwalitee = $authors->kwalitee("ZOFFIX");
-    my $name     = $authors->name("ANDY");
+    my $name     = $authors->name("ZOFFIX");
 
 See documentation for L<Acme::CPANAuthors> for more details.
 
@@ -151,7 +162,6 @@ See documentation for L<Acme::CPANAuthors> for more details.
 This class provides a hash of Russian CPAN authors' PAUSE ID and name to
 the C<Acme::CPANAuthors> module.
 
-
 =head1 MAINTENANCE
 
 If you are a Russian CPAN author not listed here, please send us your ID/name
@@ -162,313 +172,142 @@ via email or RT and we will remove your name.
 
 =head1 CONTAINED AUTHORS
 
-Now B<113> Russian CPAN authors:
+Now B<124> Russian CPAN authors:
 
-	ABALAMA   => 'Lepenkov Sergey',
-	ABEL      => 'Anton Belousov',
-	AKHOBOV   => 'Alexey Khobov',
-	AKIMOV    => 'Akimov Alexey',
-	AKR       => 'Alexey Kravchuk',
-	ALEXEYT   => 'Alexey Toptygin',
-	ALGDR     => 'Aleksandr Guidrevitch',
-	AMALTSEV  => 'Andrew Maltsev',
-	AML       => 'Alexander Lourier',
-	ANDY      => 'Andrew Shitov',
-	APLA      => 'Иван Бахчеев',
-	ARTO      => 'Artur Penttinen',
-	ASVBR     => 'Alexey Sharafutdinov',
-	ATOURBIN  => 'Alexey Tourbin',
-	AVP       => 'Alexey V. Presnyakov',
-	BASHLOV   => 'Dmitry Bashlov',
-	BOSU      => 'Boris Sukholitko',
-	BUTILW    => 'Ilya Butakov',
-	BWIZARD   => 'Arapov Denis',
-	CATONE    => 'Denis Pokataev',
-	CLEONTY   => 'Леонтий Чудинов',
-	DARKNOS   => 'Sergey Nosenko',
-	DAVINCHI  => 'Pavel Boldin',
-	DEEMON    => 'Dmitry Dorofeev',
-	DESPAIR   => 'Walery Studennikov',
-	DMITRI    => 'Dmitri Tikhonov',
-	DMITRY    => 'Dmitry Nikolayev',
-	DMITRYSOL => 'Dmitri Sologoubenko',
-	DMOW      => 'Dmitry Ovsyanko',
-	DPETROV   => 'Denis Petrov',
-	DSAMZA    => 'Dmitry Sagaev',
-	FEDOROV   => 'Dmitry Fedorov',
-	GARIEV    => 'Igor Gariev',
-	GDSL      => 'Sergey Skvortsov',
-	GLORYBOX  => 'Sergey Sinkovskiy',
-	GOSHA     => 'Okunev Igor',
-	GRAYKOT   => 'Sergey Kotenko',
-	GRIAN     => 'Анатолий Гришаев',
-	GRISHACE  => 'Gregory Belenky',
-	ICHE      => 'Ilya Chelpanov',
-	ICHUDOV   => 'Igor Chudov',
-	IFROL     => 'Иван Фролков',
-	IGORM     => 'Igor Myroshnichenko',
-	INEULANDE => 'Ivan Neulander',
-	ISTERIN   => 'Ilya Sterin',
-	KAPPA     => 'Алексей Капранов',
-	KARASIK   => 'Dmitry Karasik',
-	KES       => 'Eugen Konkov',
-	KEU       => 'Dmitry V. Kolvakh',
-	KIRILLM   => 'Кирилл Мязин',
-	KLIMKIN   => 'Alexey Klimkin',
-	KOTEROV   => 'Dmitry Koterov',
-	KPV       => 'Pavel V. Kaygorodov',
-	KSURI     => 'Aleksey Surikov',
-	KVENTIN   => 'Константин Матюхин',
-	LEO       => 'Черепанов Леонид',
-	LESV      => 'Suhanov Vadim',
-	LEXUS     => 'Usanov Alexey',
-	LIOL      => 'Lobanov Igor',
-	LOGVINON  => 'Nikolay Logvinov',
-	LONERR    => 'Oleg A. Mamontov',
-	MAKAROW   => 'Andrew V. Makarow',
-	MAXICO    => 'Maxim Kashliak',
-	MBASOV    => 'Михаил В. Басов',
-	MIT       => 'Dmitriy Dontsov',
-	MONS      => 'Mons Anderson',
-	MPG       => 'Maxim  Grigoriev',
-	NICKOLA   => 'Nickolay Kovalev',
-	NRG       => 'Odintsov Pavel',
-	NUF       => 'Dmitry Smal',
-	OLEGSHER  => 'Oleg Sher',
-	OLEKO     => 'Oleg Kobyakovskiy',
-	PLISCO    => 'Igor Plisco',
-	PRO       => 'Oleg Alexeenkov',
-	PSMIRNOV  => 'Pavel Smirnov',
-	RADKOV    => 'Alexey Radkov',
-	RHIZO     => 'Dmitry Karabanov',
-	RIIKI     => 'Oleg Prokopyev',
-	ROWAA     => 'Олег Rowaa[SR13] В. Волков',
-	RUDENKO   => 'Alexei Rudenko',
-	RUSAKOV   => 'Sergey Rusakov',
-	RUZ       => 'Ruslan U. Zakirov',
-	SAFRONOV  => 'Vladislav A. Safronov',
-	SASHA     => 'Alex Protasenko',
-	SAVA      => 'Сава Чанков',
-	SERG      => 'Sergei Golubchik',
-	SERGEY    => 'Sergey Gribov',
-	SERGEYCHE => 'Sergey Chernyshev',
-	SHARIFULN => 'Анатолий Шарифулин',
-	SNEMAROV  => 'Sergei A. Nemarov',
-	SPECTRUM  => 'Черненко Эдуард Павлович',
-	STELLAR   => 'Andrei V. Shetuhin',
-	SWAJ      => 'Alexey Semenoff',
-	SWINED    => 'Alexey Alexandrov',
-	SYBER     => 'Олег Пронин',
-	SYP       => 'Станислав Пусеп',
-	TOLIKL    => 'Anatoly K. Lasareff',
-	TOYVO     => 'Anton Tayanovskyy',
-	UNERA     => 'Dmitry E. Oboukhov',
-	USTIANSKY => 'Vadim O. Ustiansky',
-	VADIML    => 'Vadim Likhota (Вадим Лихота)',
-	VANY      => 'Ivan B. Serezhkin',
-	VICTORI   => 'Victor Igumnov',
-	VKON      => 'Vadim Konovalov',
-	VLADB     => 'Vladimir Bogdanov',
-	VOVKASM   => 'Vladimir Timofeev',
-	XFIRE     => 'Ilya Obshadko',
-	YKAR      => 'Yuri Karaban',
-	YKOSTYLEV => 'Yuri Kostylev',
-	YURAN     => 'Nevinitsin Yury',
-	ZAG       => 'Zahatski Aliaksandr',
-	ZMIJ      => 'Sergei A. Fedorov',
-	ZOFFIX    => 'Zoffix Znet',
-
-
-And B<73> have PAUSE id, but they didn't upload any module:
-
-	ADTIM     => 'Тимур Кондратьев',
-	ALXPLDEV  => 'Kononov Alexey',
-	AMANOKHIN => 'Alexey E.Manokhin',
-	AMONARCH  => 'Kirill Frolov',
-	AVOROBEY  => 'Anatoly Vorobey',
-	AZINGER   => 'Alexey Zinger',
-	BAT       => 'Тимур Бакеев',
-	BLINCHIK  => 'Vladislav',
-	BURNASH   => 'Anton Burnashev',
-	CTAPUK    => 'Dmitriy Repin',
-	DENIS     => 'Денис Терещенко',
-	DEVIS     => 'Мусин Роман',
-	DIMMA     => 'Vadim Suvorov',
-	DIVER     => 'Максим Дуюнов',
-	DMA       => 'Dmitri Alenitchev',
-	DVRYABOY  => 'Dmitriy Ryaboy',
-	DZEMA     => 'Дмитрий Дзема',
-	GAMBURGER => 'Мякинин Тимур Алексеевич',
-	GREEN     => 'Evdokimov Denis',
-	HELLMAN   => 'Yuri A. Kabaenkov',
-	HORD      => 'Denis S Chuprunov',
-	HRG       => 'Yury Kopyl',
-	IFOMICHEV => 'Ivan Fomichev',
-	IGSTAR    => 'Sergey Rybalko',
-	IOK       => 'Igor Okunev',
-	IPECHORIN => 'Иван А. Печорин',
-	JAAN      => 'Иван Валентиныч Муравьёв',
-	JUPITER   => 'Ivan Ponomarev',
-	KAZIMIROV => 'Dmitry Kazimirov',
-	KIRILL    => 'Кирилл',
-	KOTEROFF  => 'Dmitry Koteroff',
-	KUDINOV   => 'Pavel Kudinov',
-	LINCHUS   => 'Sein Sergey',
-	MADFROG   => 'Сергей Евстегнеев',
-	MARTYNOFF => 'Sergey Martynoff',
-	MARTYNOV  => 'Сергей Мартынов',
-	MAXX      => 'Suslov Maxim',
-	MINAKOV   => 'Vladimir Minakov',
-	MISAKA    => 'Mishka Gorodnitzky',
-	MMK       => 'Мартин Маринов',
-	MOTONAROL => 'Averyanov Ilya',
-	MYAKININ  => 'Timur Myakinin',
-	NAB       => 'Nickolay Briginets',
-	OBOGREW   => 'Nikolay Kuznetsov',
-	OKOLOBOV  => 'Oleg Kolobov',
-	OLPA      => 'Oleg A. Paraschenko',
-	RAKESH    => 'Rakesh Alex',
-	RANDIR    => 'Sergey Aleynikov',
-	RANGER    => 'Alexey Stroganov',
-	RASSIE    => 'Николай Прокошенко',
-	SAPA      => 'Андрей Сапожников',
-	SAV       => 'Andrey Smorodin',
-	SCOUNDREL => 'Alexey Kovyrin',
-	SEZAY     => 'Sergei Zaytsev',
-	SHADOVV   => 'Victor M Elfimov',
-	SHV       => 'Sharypov Alexey',
-	SLEONOV   => 'Sergey Leonovich',
-	SODASODA  => 'Ilya Soda',
-	SOKOL     => 'Pavel Sokol',
-	SOVA      => 'Vladimir Sovetov',
-	SPR       => 'Сергей Пригожий',
-	STEALTHY  => 'Oleg Nikitin',
-	STSAREV   => 'Sergei Tsarev',
-	TEAK      => 'Sergey Redin',
-	TECHCODE  => 'Aleksandar Petrović',
-	TED       => 'Ruslan (Ted) Kharitonov',
-	TMULEVICH => 'Sergey Tomoulevitch',
-	UJIN      => 'Зарецкий Евгений Петрович',
-	VLADISLAV => 'Sergey',
-	VMARCHEN  => 'Vladimir Marchenko',
-	VPOROSHIN => 'Vladimir Poroshin',
-	VVD       => 'Andrey Yakovlev',
-	ZHR       => 'Vladimir Zhirov',
+    ABALAMA   => 'Lepenkov Sergey',
+    ABEL      => 'Anton Belousov',
+    AKHOBOV   => 'Alexey Khobov',
+    AKIMOV    => 'Akimov Alexey',
+    AKR       => 'Alexey Kravchuk',
+    ALEXEYT   => 'Alexey Toptygin',
+    ALGDR     => 'Aleksandr Guidrevitch',
+    AMALTSEV  => 'Andrew Maltsev',
+    ANDY      => 'Andrew Shitov',
+    APLA      => 'Иван Бахчеев',
+    ARTO      => 'Artur Penttinen',
+    ASVBR     => 'Alexey Sharafutdinov',
+    ATOURBIN  => 'Alexey Tourbin',
+    AVP       => 'Alexey V. Presnyakov',
+    BASHLOV   => 'Dmitry Bashlov',
+    BEROV     => 'Красимир Беров',
+    BOSU      => 'Boris Sukholitko',
+    BUTILW    => 'Ilya Butakov',
+    CATONE    => 'Denis Pokataev',
+    CLEONTY   => 'Леонтий Чудинов',
+    CYBER     => 'Ivan M Nanev',
+    DAVINCHI  => 'Pavel Boldin',
+    DEEMON    => 'Dmitry Dorofeev',
+    DESPAIR   => 'Walery Studennikov',
+    DMITRI    => 'Dmitri Tikhonov',
+    DMITRY    => 'Dmitry Nikolayev',
+    DMITRYSOL => 'Dmitri Sologoubenko',
+    DMOW      => 'Dmitry Ovsyanko',
+    DPETROV   => 'Denis Petrov',
+    DSAMZA    => 'Dmitry Sagaev',
+    DZHARIY   => 'Дмитрий Жарий',
+    EGORSH    => 'Egor Shipovalov',
+    EJS       => 'Eugen Sobchenko',
+    FEDOROV   => 'Dmitry Fedorov',
+    GARIEV    => 'Igor Gariev',
+    GDSL      => 'Sergey Skvortsov',
+    GLORYBOX  => 'Sergey Sinkovskiy',
+    GOSHA     => 'Okunev Igor',
+    GRAYKOT   => 'Sergey Kotenko',
+    GRIAN     => 'Анатолий Гришаев',
+    GRISHACE  => 'Gregory Belenky',
+    GRUBER    => 'Anton Berezin',
+    GUGU      => 'Андрей Костенко',
+    ICHE      => 'Ilya Chelpanov',
+    ICHUDOV   => 'Igor Chudov',
+    IFROL     => 'Иван Фролков',
+    IGORM     => 'Igor Myroshnichenko',
+    INEULANDE => 'Ivan Neulander',
+    ISTERIN   => 'Ilya Sterin',
+    KAPPA     => 'Алексей Капранов',
+    KARASIK   => 'Dmitry Karasik',
+    KES       => 'Eugen Konkov',
+    KEU       => 'Dmitry V. Kolvakh',
+    KIRILLM   => 'Кирилл Мязин',
+    KLIMKIN   => 'Alexey Klimkin',
+    KOTEROV   => 'Dmitry Koterov',
+    KPV       => 'Pavel V. Kaygorodov',
+    KVENTIN   => 'Константин Матюхин',
+    LEO       => 'Черепанов Леонид',
+    LESV      => 'Suhanov Vadim',
+    LEXUS     => 'Usanov Alexey',
+    LIOL      => 'Lobanov Igor',
+    LOGVINON  => 'Nikolay Logvinov',
+    MAKAROW   => 'Andrew V. Makarow',
+    MAXICO    => 'Maxim Kashliak',
+    MBASOV    => 'Михаил В. Басов',
+    MIT       => 'Dmitriy Dontsov',
+    MONS      => 'Mons Anderson',
+    MPG       => 'Maxim  Grigoriev',
+    NICKOLA   => 'Nickolay Kovalev',
+    NIKIP     => 'Nikolay Pelov',
+    NIKOLAY   => 'Nikolay Bachiyski',
+    NRG       => 'Odintsov Pavel',
+    OLEGSHER  => 'Oleg Sher',
+    OLEKO     => 'Oleg Kobyakovskiy',
+    OMEGA     => 'Десислав Каменов/Desislav Kamenov',
+    PANOLEX   => 'Олександр Панчук',
+    PLISCO    => 'Igor Plisco',
+    PRO       => 'Oleg Alexeenkov',
+    PSMIRNOV  => 'Pavel Smirnov',
+    QUEVLAR   => 'Igor Sanchez-Puls',
+    RADKOV    => 'Alexey Radkov',
+    RHIZO     => 'Dmitry Karabanov',
+    RIIKI     => 'Oleg Prokopyev',
+    ROWAA     => 'Олег &quot;Rowaa[SR13]&quot; В. Волков',
+    RUDENKO   => 'Alexei Rudenko',
+    RUSAKOV   => 'Sergey Rusakov',
+    RUZ       => 'Ruslan U. Zakirov',
+    SAFRONOV  => 'Vladislav A. Safronov',
+    SASHA     => 'Alex Protasenko',
+    SAVA      => 'Сава Чанков',
+    SERG      => 'Sergei Golubchik',
+    SERGEY    => 'Sergey Gribov',
+    SERGEYCHE => 'Sergey Chernyshev',
+    SHARIFULN => 'Анатолий Шарифулин',
+    SKOLYCHEV => 'Sergey V. Kolychev',
+    SNEMAROV  => 'Sergei A. Nemarov',
+    SPECTRUM  => 'Черненко Эдуард Павлович',
+    STELLAR   => 'Andrei V. Shetuhin',
+    SWAJ      => 'Alexey Semenoff',
+    SWINED    => 'Alexey Alexandrov',
+    SYBER     => 'Олег Пронин',
+    SYP       => 'Станислав Пусеп',
+    TOLIKL    => 'Anatoly K. Lasareff',
+    TOYVO     => 'Anton Tayanovskyy',
+    TTOD      => 'Тодор Тодоров',
+    USTIANSKY => 'Vadim O. Ustiansky',
+    VADIM     => 'Vadim Ponomarenko',
+    VADIML    => 'Vadim Likhota (Вадим Лихота)',
+    VADIMT    => 'Vadim Trochinsky',
+    VANY      => 'Ivan B. Serezhkin',
+    VICTORI   => 'Victor Igumnov',
+    VIY       => 'Igor Yu. Vlasenko',
+    VKON      => 'Vadim Konovalov',
+    VLADB     => 'Vladimir Bogdanov',
+    VOVKASM   => 'Vladimir Timofeev',
+    VTI       => 'Вячеслав Тихановский',
+    XFIRE     => 'Ilya Obshadko',
+    YKAR      => 'Yuri Karaban',
+    YKOSTYLEV => 'Yuri Kostylev',
+    YURAN     => 'Nevinitsin Yury',
+    ZMIJ      => 'Sergei A. Fedorov',
+    ZOFFIX    => 'Zoffix Znet'
 
 =head1 SEE ALSO
 
-=head2 Base
-
-L<Acme::CPANAuthors>
-L<Acme::CPANAuthors::Register>
-L<Acme::CPANAuthors::Utils::Kwalitee>
-
-=head2 Real
-
-=over 15
-
-=item * L<Acme::CPANAuthors::Austrian>
-
-We are Austrian CPAN authors
-
-=item * L<Acme::CPANAuthors::Brazilian>
-
-We are Brazilian CPAN authors
-
-=item * L<Acme::CPANAuthors::Canadian>
-
-We are Austrian CPAN authors
-
-=item * L<Acme::CPANAuthors::Chinese>
-
-We are Canadian CPAN authors
-
-=item * L<Acme::CPANAuthors::French>
-
-We are French CPAN authors
-
-=item * L<Acme::CPANAuthors::Icelandic>
-
-We are Icelandic CPAN authors
-
-=item * L<Acme::CPANAuthors::Israeli>
-
-We are Israeli CPAN authors
-
-=item * L<Acme::CPANAuthors::Italian>
-
-We are Italian CPAN authors
-
-=item * L<Acme::CPANAuthors::Japanese>
-
-We are Japanese CPAN authors
-
-=item * L<Acme::CPANAuthors::Norwegian>
-
-We are Norwegian CPAN authors
-
-=item * L<Acme::CPANAuthors::Portuguese>
-
-We are the Portuguese CPAN authors
-
-=item * L<Acme::CPANAuthors::Russian>
-
-We are the Russian CPAN authors 
-
-=item * L<Acme::CPANAuthors::Taiwanese>
-
-We are the Taiwanese CPAN authors
-
-=item * L<Acme::CPANAuthors::Turkish>
-
-We are the Turkish CPAN authors
-
-=item * L<Acme::CPANAuthors::Ukrainian>
-
-We are the Ukrainian CPAN authors
-
-=back
-
-=head2 Fun and etc
-
-=over 6
-
-=item * L<Acme::CPANAuthors::Not>
-
-We are not CPAN authors
-
-=item * L<Acme::CPANAuthors::Acme::CPANAuthors::Authors>
-
-We are CPAN authors who have authored Acme::CPANAuthors modules
-
-=item * L<Acme::CPANAuthors::You::re_using>
-
-We are the CPAN authors that have written the modules installed on your perl!
-
-=item * L<Acme::CPANAuthors::GeekHouse>
-
-We're CPAN Authors in The Geek House
-
-=item * L<Acme::CPANAuthors::Misanthrope>
-
-The CPAN authors who see into your soul with perfect clarity. 
-
-=item * L<Acme::CPANAuthors::CodeRepos>
-
-We are CPAN authors using CodeRepos
-
-=back
-
-=head2 Search
-
-L<http://search.cpan.org/search?query=Acme%3A%3ACPANAuthors&mode=all>
-
+L<Acme::CPANAuthors> L<http://search.cpan.org/search?query=Acme%3A%3ACPANAuthors&mode=all>
 
 =head1 AUTHOR
 
-Anatoly Sharifulin, C<< <sharifulin at gmail.com> >>
-
 Zoffix Znet, C<< <'zoffix at cpan.org'> >>
+(L<http://zoffix.com/>, L<http://haslayout.net/>, L<http://zofdesign.com/>)
+
+Anatoly Sharifulin, C<< <sharifulin at gmail.com> >>
 
 =head1 BUGS
 
@@ -488,7 +327,7 @@ You can also look for information at:
 
 =item * Github
 
-L<http://github.com/sharifulin/acme-cpanauthors-russian/tree/master>
+http://github.com/sharifulin/acme-cpanauthors-russian/tree/master
 
 =item * RT: CPAN's request tracker
 
@@ -510,10 +349,10 @@ L<http://search.cpan.org/dist/Acme-CPANAuthors-Russian>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2009 by Anatoly Sharifulin.
-
 Copyright (C) 2008-2009 by Zoffix Znet.
 
+Copyright (C) 2009 by Anatoly Sharifulin.
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
